@@ -32,7 +32,8 @@ METADATA_PATH = _os.path.join(_current_path, "metadata.json")
 
 _js_dist = [
     {
-        'relative_package_path': 'bundle.js',    
+        'relative_package_path': 'dash_large_upload_component.min.js',
+        'dev_package_path': 'dash_large_upload_component.dev.js',   
         'namespace': package_name
     }
 ]
